.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide_addons.html
   This text does not appear on pypi or github. It is a comment.

==============================================================================
collective.smartlink
==============================================================================


Features
--------

- Adds an extra field to set internal link as reference.
- If the link is broken anonymous users are redirect to the site root.


Installation
------------

Install collective.smartlink by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.smartlink


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/RedTurtle/collective.smartlink/issues
- Source Code: https://github.com/RedTurtle/collective.smartlink


Support
-------

If you are having issues, please let us know.


License
-------

The project is licensed under the GPLv2.
